<ol class="breadcrumb">
    {% if 'export_' in request.resolver_match.url_name %}
        <li>
            <a href="{% url 'geokey_export:index' %}">Home</a>
        </li>
    {% endif %}

    {% if request.resolver_match.url_name == 'export_overview' %}
        <li class="active">Export overview</li>
    {% endif %}

    {% if request.resolver_match.url_name == 'export_create' %}
        <li class="active">Create new export</li>
    {% endif %}
</ol>
