{% extends 'base.html' %}
{% load export_tags %}

{% block title %} | Export{% endblock %}

{% block main %}
{% include 'export_header.html' %}

<div class="container">
    <div class="row">
        <div class="col-md-8 col-md-offset-2">
            <h3 class="header">{{ export.name }}</h3>

            <p class="lead">Select the format you want to access:</p>

            <table class="table table-hover">
                <tr>
                    <td>KML</td>

                    <td>
                        <a href="{% url 'geokey_export:export_to_renderer' export.urlhash %}.kml">{{ export.urlhash }}.kml</a>
                    </td>
                </tr>

                <tr>
                    <td>GeoJSON</td>

                    <td>
                        <a href="{% url 'geokey_export:export_to_renderer' export.urlhash %}.json">{{ export.urlhash }}.json</a>
                    </td>
                </tr>
            </table>
        </div>
    </div>
</div>
{% endblock %}
